#include <vtkActor.h>
#include <vtkHandleWidget.h>
#include <vtkNamedColors.h>
#include <vtkNew.h>
#include <vtkPointHandleRepresentation2D.h>
#include <vtkPolyData.h>
#include <vtkPolyDataMapper.h>
#include <vtkProperty.h>
#include <vtkRegularPolygonSource.h>
#include <vtkRenderWindow.h>
#include <vtkRenderWindowInteractor.h>
#include <vtkRenderer.h>
#include <vtkSphereSource.h>

int main(int, char*[])
{
  vtkNew<vtkNamedColors> colors;

  // Create the RenderWindow, Renderer and both Actors
  //
  vtkNew<vtkRenderer> ren1;
  vtkNew<vtkRenderWindow> renWin;
  renWin->AddRenderer(ren1);
  renWin->SetWindowName("My program");

  vtkNew<vtkRenderWindowInteractor> iren;
  iren->SetRenderWindow(renWin);

  vtkNew<vtkSphereSource> sphereSource;
  sphereSource->Update();
  vtkNew<vtkPolyDataMapper> mapper;
  mapper->SetInputConnection(sphereSource->GetOutputPort());
  vtkNew<vtkActor> actor;
  actor->SetMapper(mapper);
  actor->GetProperty()->SetColor(colors->GetColor3d("MistyRose").GetData());

  vtkNew<vtkRegularPolygonSource> cursor2D;
  cursor2D->SetNumberOfSides(20);
  cursor2D->GeneratePolygonOn();
  cursor2D->SetRadius(23);
  cursor2D->Update();

  vtkNew<vtkPointHandleRepresentation2D> handleRep;
  double pos[3]{80, 80, 40};
  handleRep->SetWorldPosition(pos);
  handleRep->ActiveRepresentationOn();
  handleRep->PickableOn();
  handleRep->SetHandleSize(18);
  handleRep->SetCursorShape(cursor2D->GetOutput());

  vtkNew<vtkHandleWidget> handleWidget;
  handleWidget->SetInteractor(iren);
  handleWidget->SetRepresentation(handleRep);

  ren1->SetBackground(colors->GetColor3d("DarkSlateGray").GetData());
  ren1->AddActor(actor);

  renWin->SetSize(300, 300);
  renWin->Render();

  handleWidget->ProcessEventsOn();
  handleWidget->On();

  iren->Initialize();
  iren->Start();

  return EXIT_SUCCESS;
}
